# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.Normalization = QtWidgets.QVBoxLayout(self.groupBox)
        self.Normalization.setObjectName("Normalization")
        self.chooseDataFormLayout = QtWidgets.QFormLayout()
        self.chooseDataFormLayout.setObjectName("chooseDataFormLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseDataComboBox)
        self.Normalization.addLayout(self.chooseDataFormLayout)
        self.varToNormalizeVerticalLayout = QtWidgets.QVBoxLayout()
        self.varToNormalizeVerticalLayout.setObjectName("varToNormalizeVerticalLayout")
        self.varToNormalizeLabel = QtWidgets.QLabel(self.groupBox)
        self.varToNormalizeLabel.setObjectName("varToNormalizeLabel")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeLabel)
        self.varToNormalizeListWidget = QtWidgets.QListWidget(self.groupBox)
        self.varToNormalizeListWidget.setObjectName("varToNormalizeListWidget")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeListWidget)
        self.Normalization.addLayout(self.varToNormalizeVerticalLayout)
        self.waveLengthLayout = QtWidgets.QGridLayout()
        self.waveLengthLayout.setObjectName("waveLengthLayout")
        self.minimumWavelengthLabel = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel.setObjectName("minimumWavelengthLabel")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel, 0, 0, 1, 1)
        self.minimumWavelengthSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox.setObjectName("minimumWavelengthSpinBox")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox, 0, 1, 1, 1)
        self.maximumWavelengthLabel = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel.setObjectName("maximumWavelengthLabel")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel, 0, 2, 1, 1)
        self.maximumWavelengthSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox.setObjectName("maximumWavelengthSpinBox")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox, 0, 3, 1, 1)
        self.minimumWavelengthLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_2.setObjectName("minimumWavelengthLabel_2")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_2, 1, 0, 1, 1)
        self.minimumWavelengthSpinBox_2 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_2.setObjectName("minimumWavelengthSpinBox_2")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_2, 1, 1, 1, 1)
        self.maximumWavelengthLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_2.setObjectName("maximumWavelengthLabel_2")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_2, 1, 2, 1, 1)
        self.maximumWavelengthSpinBox_2 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_2.setObjectName("maximumWavelengthSpinBox_2")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_2, 1, 3, 1, 1)
        self.minimumWavelengthLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_3.setObjectName("minimumWavelengthLabel_3")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_3, 2, 0, 1, 1)
        self.minimumWavelengthSpinBox_3 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_3.setObjectName("minimumWavelengthSpinBox_3")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_3, 2, 1, 1, 1)
        self.maximumWavelengthLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_3.setObjectName("maximumWavelengthLabel_3")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_3, 2, 2, 1, 1)
        self.maximumWavelengthSpinBox_3 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_3.setObjectName("maximumWavelengthSpinBox_3")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_3, 2, 3, 1, 1)
        self.minimumWavelengthLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_4.setObjectName("minimumWavelengthLabel_4")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_4, 3, 0, 1, 1)
        self.minimumWavelengthSpinBox_4 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_4.setObjectName("minimumWavelengthSpinBox_4")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_4, 3, 1, 1, 1)
        self.maximumWavelengthLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_4.setObjectName("maximumWavelengthLabel_4")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_4, 3, 2, 1, 1)
        self.maximumWavelengthSpinBox_4 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_4.setObjectName("maximumWavelengthSpinBox_4")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_4, 3, 3, 1, 1)
        self.minimumWavelengthLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_5.setObjectName("minimumWavelengthLabel_5")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_5, 4, 0, 1, 1)
        self.minimumWavelengthSpinBox_5 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_5.setObjectName("minimumWavelengthSpinBox_5")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_5, 4, 1, 1, 1)
        self.maximumWavelengthLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_5.setObjectName("maximumWavelengthLabel_5")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_5, 4, 2, 1, 1)
        self.maximumWavelengthSpinBox_5 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_5.setObjectName("maximumWavelengthSpinBox_5")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_5, 4, 3, 1, 1)
        self.minimumWavelengthLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_6.setObjectName("minimumWavelengthLabel_6")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_6, 5, 0, 1, 1)
        self.minimumWavelengthSpinBox_6 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_6.setObjectName("minimumWavelengthSpinBox_6")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_6, 5, 1, 1, 1)
        self.maximumWavelengthLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_6.setObjectName("maximumWavelengthLabel_6")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_6, 5, 2, 1, 1)
        self.maximumWavelengthSpinBox_6 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_6.setObjectName("maximumWavelengthSpinBox_6")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_6, 5, 3, 1, 1)
        self.minimumWavelengthLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_7.setObjectName("minimumWavelengthLabel_7")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_7, 6, 0, 1, 1)
        self.minimumWavelengthSpinBox_7 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_7.setObjectName("minimumWavelengthSpinBox_7")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_7, 6, 1, 1, 1)
        self.maximumWavelengthLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_7.setObjectName("maximumWavelengthLabel_7")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_7, 6, 2, 1, 1)
        self.maximumWavelengthSpinBox_7 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_7.setObjectName("maximumWavelengthSpinBox_7")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_7, 6, 3, 1, 1)
        self.minimumWavelengthLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_8.setObjectName("minimumWavelengthLabel_8")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_8, 7, 0, 1, 1)
        self.minimumWavelengthSpinBox_8 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_8.setObjectName("minimumWavelengthSpinBox_8")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_8, 7, 1, 1, 1)
        self.maximumWavelengthLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_8.setObjectName("maximumWavelengthLabel_8")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_8, 7, 2, 1, 1)
        self.maximumWavelengthSpinBox_8 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_8.setObjectName("maximumWavelengthSpinBox_8")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_8, 7, 3, 1, 1)
        self.minimumWavelengthLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_9.setObjectName("minimumWavelengthLabel_9")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_9, 8, 0, 1, 1)
        self.minimumWavelengthSpinBox_9 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_9.setObjectName("minimumWavelengthSpinBox_9")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_9, 8, 1, 1, 1)
        self.maximumWavelengthLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_9.setObjectName("maximumWavelengthLabel_9")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_9, 8, 2, 1, 1)
        self.maximumWavelengthSpinBox_9 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_9.setObjectName("maximumWavelengthSpinBox_9")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_9, 8, 3, 1, 1)
        self.minimumWavelengthLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_10.setObjectName("minimumWavelengthLabel_10")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_10, 9, 0, 1, 1)
        self.minimumWavelengthSpinBox_10 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_10.setObjectName("minimumWavelengthSpinBox_10")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_10, 9, 1, 1, 1)
        self.maximumWavelengthLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_10.setObjectName("maximumWavelengthLabel_10")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_10, 9, 2, 1, 1)
        self.maximumWavelengthSpinBox_10 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_10.setObjectName("maximumWavelengthSpinBox_10")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_10, 9, 3, 1, 1)
        self.minimumWavelengthLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_11.setObjectName("minimumWavelengthLabel_11")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_11, 10, 0, 1, 1)
        self.minimumWavelengthSpinBox_11 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_11.setObjectName("minimumWavelengthSpinBox_11")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_11, 10, 1, 1, 1)
        self.maximumWavelengthLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_11.setObjectName("maximumWavelengthLabel_11")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_11, 10, 2, 1, 1)
        self.maximumWavelengthSpinBox_11 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_11.setObjectName("maximumWavelengthSpinBox_11")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_11, 10, 3, 1, 1)
        self.minimumWavelengthLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_12.setObjectName("minimumWavelengthLabel_12")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_12, 11, 0, 1, 1)
        self.minimumWavelengthSpinBox_12 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_12.setObjectName("minimumWavelengthSpinBox_12")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_12, 11, 1, 1, 1)
        self.maximumWavelengthLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_12.setObjectName("maximumWavelengthLabel_12")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_12, 11, 2, 1, 1)
        self.maximumWavelengthSpinBox_12 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_12.setObjectName("maximumWavelengthSpinBox_12")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_12, 11, 3, 1, 1)
        self.minimumWavelengthLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_13.setObjectName("minimumWavelengthLabel_13")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_13, 12, 0, 1, 1)
        self.minimumWavelengthSpinBox_13 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_13.setObjectName("minimumWavelengthSpinBox_13")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_13, 12, 1, 1, 1)
        self.maximumWavelengthLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_13.setObjectName("maximumWavelengthLabel_13")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_13, 12, 2, 1, 1)
        self.maximumWavelengthSpinBox_13 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_13.setObjectName("maximumWavelengthSpinBox_13")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_13, 12, 3, 1, 1)
        self.minimumWavelengthLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_14.setObjectName("minimumWavelengthLabel_14")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_14, 13, 0, 1, 1)
        self.minimumWavelengthSpinBox_14 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_14.setObjectName("minimumWavelengthSpinBox_14")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_14, 13, 1, 1, 1)
        self.maximumWavelengthLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_14.setObjectName("maximumWavelengthLabel_14")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_14, 13, 2, 1, 1)
        self.maximumWavelengthSpinBox_14 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_14.setObjectName("maximumWavelengthSpinBox_14")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_14, 13, 3, 1, 1)
        self.minimumWavelengthLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.minimumWavelengthLabel_15.setObjectName("minimumWavelengthLabel_15")
        self.waveLengthLayout.addWidget(self.minimumWavelengthLabel_15, 14, 0, 1, 1)
        self.maximumWavelengthLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.maximumWavelengthLabel_15.setObjectName("maximumWavelengthLabel_15")
        self.waveLengthLayout.addWidget(self.maximumWavelengthLabel_15, 14, 2, 1, 1)
        self.maximumWavelengthSpinBox_15 = QtWidgets.QSpinBox(self.groupBox)
        self.maximumWavelengthSpinBox_15.setObjectName("maximumWavelengthSpinBox_15")
        self.waveLengthLayout.addWidget(self.maximumWavelengthSpinBox_15, 14, 3, 1, 1)
        self.minimumWavelengthSpinBox_15 = QtWidgets.QSpinBox(self.groupBox)
        self.minimumWavelengthSpinBox_15.setObjectName("minimumWavelengthSpinBox_15")
        self.waveLengthLayout.addWidget(self.minimumWavelengthSpinBox_15, 14, 1, 1, 1)
        self.Normalization.addLayout(self.waveLengthLayout)
        self.addDelRangeLayout = QtWidgets.QHBoxLayout()
        self.addDelRangeLayout.setObjectName("addDelRangeLayout")
        self.nRangesLabel = QtWidgets.QLabel(self.groupBox)
        self.nRangesLabel.setObjectName("nRangesLabel")
        self.addDelRangeLayout.addWidget(self.nRangesLabel)
        self.rangeCountSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.rangeCountSpinBox.setMaximum(14)
        self.rangeCountSpinBox.setObjectName("rangeCountSpinBox")
        self.addDelRangeLayout.addWidget(self.rangeCountSpinBox)
        self.Normalization.addLayout(self.addDelRangeLayout)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Normalization"))
        self.chooseDataLabel.setText(("Choose data"))
        self.varToNormalizeLabel.setText(("Variable to normalize"))
        self.minimumWavelengthLabel.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_2.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_2.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_3.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_3.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_4.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_4.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_5.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_5.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_6.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_6.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_7.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_7.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_8.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_8.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_9.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_9.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_10.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_10.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_11.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_11.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_12.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_12.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_13.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_13.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_14.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_14.setText(("Maximum wavelength"))
        self.minimumWavelengthLabel_15.setText(("Minimum wavelength"))
        self.maximumWavelengthLabel_15.setText(("Maximum wavelength"))
        self.nRangesLabel.setText(("Number of Ranges:"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.kernel_ridge import KernelRidge

from point_spectra_gui.ui.KRR import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, KernelRidge, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        print("alpha", self.alpha)
        print("kernel", self.kernel)
        print("gamma", self.gamma)
        print("degree", self.degree)
        print("coef0", self.coef0)
        print("kernel_params", self.kernel_params)
        self.alphaSpinBox.setValue(self.alpha)
        self.kernelParametersLineEdit.setText(str(self.kernel_params))
        self.gammaLineEdit.setText(str(self.gamma))
        self.degreeDoubleSpinBox.setValue(self.degree)
        self.coeff0DoubleSpinBox.setValue(self.coef0)
        self.kernelLineEdit.setText(str(self.kernel))

    def function(self):
        k_attrib = {'None': None}
        params = {'alpha': self.alphaSpinBox.value(),
                  'kernel': self.kernelLineEdit.text(),
                  'gamma': self.gammaLineEdit.text(),
                  'degree': self.degreeDoubleSpinBox.value(),
                  'coef0': self.coeff0DoubleSpinBox.value(),
                  'kernel_params': k_attrib[self.kernelParametersLineEdit.text()]}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.alphaLabel = QtWidgets.QLabel(self.groupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.alphaLabel)
        self.alphaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.alphaDoubleSpinBox.setEnabled(False)
        self.alphaDoubleSpinBox.setMaximum(999999999.0)
        self.alphaDoubleSpinBox.setProperty("value", 1.0)
        self.alphaDoubleSpinBox.setObjectName("alphaDoubleSpinBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.alphaDoubleSpinBox)
        self.maxNumOfIterationsLabel = QtWidgets.QLabel(self.groupBox)
        self.maxNumOfIterationsLabel.setObjectName("maxNumOfIterationsLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maxNumOfIterationsLabel)
        self.maxNumOfIterationsSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.maxNumOfIterationsSpinBox.setMaximum(999999999)
        self.maxNumOfIterationsSpinBox.setProperty("value", 1000)
        self.maxNumOfIterationsSpinBox.setObjectName("maxNumOfIterationsSpinBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maxNumOfIterationsSpinBox)
        self.toleranceLabel = QtWidgets.QLabel(self.groupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.fitInterceptLabel = QtWidgets.QLabel(self.groupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.fitInterceptCheckBox.setChecked(True)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.forcePositiveCoefficientsLabel = QtWidgets.QLabel(self.groupBox)
        self.forcePositiveCoefficientsLabel.setObjectName("forcePositiveCoefficientsLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.forcePositiveCoefficientsLabel)
        self.forcePositiveCoefficientsCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.forcePositiveCoefficientsCheckBox.setObjectName("forcePositiveCoefficientsCheckBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.forcePositiveCoefficientsCheckBox)
        self.optimizeWCrossValidaitonLabel = QtWidgets.QLabel(self.groupBox)
        self.optimizeWCrossValidaitonLabel.setObjectName("optimizeWCrossValidaitonLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.optimizeWCrossValidaitonLabel)
        self.optimizeWCrossValidaitonCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.optimizeWCrossValidaitonCheckBox.setChecked(True)
        self.optimizeWCrossValidaitonCheckBox.setObjectName("optimizeWCrossValidaitonCheckBox")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.optimizeWCrossValidaitonCheckBox)
        self.toleranceDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.toleranceDoubleSpinBox.setDecimals(5)
        self.toleranceDoubleSpinBox.setMaximum(999999999.0)
        self.toleranceDoubleSpinBox.setProperty("value", 0.0001)
        self.toleranceDoubleSpinBox.setObjectName("toleranceDoubleSpinBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.toleranceDoubleSpinBox)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        self.optimizeWCrossValidaitonCheckBox.toggled['bool'].connect(self.alphaDoubleSpinBox.setDisabled)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.alphaDoubleSpinBox, self.maxNumOfIterationsSpinBox)
        Form.setTabOrder(self.maxNumOfIterationsSpinBox, self.toleranceDoubleSpinBox)
        Form.setTabOrder(self.toleranceDoubleSpinBox, self.fitInterceptCheckBox)
        Form.setTabOrder(self.fitInterceptCheckBox, self.forcePositiveCoefficientsCheckBox)
        Form.setTabOrder(self.forcePositiveCoefficientsCheckBox, self.optimizeWCrossValidaitonCheckBox)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.alphaLabel.setText(("Alpha"))
        self.maxNumOfIterationsLabel.setText(("Max # of iterations"))
        self.toleranceLabel.setText(("Tolerance"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.forcePositiveCoefficientsLabel.setText(("Force positive coefficients"))
        self.optimizeWCrossValidaitonLabel.setText(("Optimize w/ Cross Validaiton (Ignores alpha)"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setObjectName("formLayout")
        self.CalTran_dataSetRefLabel = QtWidgets.QLabel(self.formGroupBox)
        self.CalTran_dataSetRefLabel.setObjectName("CalTran_dataSetRefLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.CalTran_dataSetRefLabel)
        self.CalTran_dataSetRefLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.CalTran_dataSetRefLineEdit.setObjectName("CalTran_dataSetRefLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.CalTran_dataSetRefLineEdit)
        self.CalTran_dataSetTransformLabel = QtWidgets.QLabel(self.formGroupBox)
        self.CalTran_dataSetTransformLabel.setObjectName("CalTran_dataSetTransformLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.CalTran_dataSetTransformLabel)
        self.CalTran_dataSetTransformLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.CalTran_dataSetTransformLineEdit.setObjectName("CalTran_dataSetTransformLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.CalTran_dataSetTransformLineEdit)
        self.CalTran_columnToMatchLabel = QtWidgets.QLabel(self.formGroupBox)
        self.CalTran_columnToMatchLabel.setObjectName("CalTran_columnToMatchLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.CalTran_columnToMatchLabel)
        self.CalTran_columnToMatchComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.CalTran_columnToMatchComboBox.setObjectName("CalTran_columnToMatchComboBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.CalTran_columnToMatchComboBox)
        self.methodLabel = QtWidgets.QLabel(self.formGroupBox)
        self.methodLabel.setObjectName("methodLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.methodLabel)
        self.methodComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.methodComboBox.setObjectName("methodComboBox")
        self.methodComboBox.addItem("")
        self.methodComboBox.addItem("")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.methodComboBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("Calibration Transfer"))
        self.CalTran_dataSetRefLabel.setText(("Reference Data Set:"))
        self.CalTran_dataSetTransformLabel.setText(("Data Set to Transform:"))
        self.CalTran_columnToMatchLabel.setText(("Column to Match:"))
        self.methodLabel.setText(("Method:"))
        self.methodComboBox.setItemText(0, ("LRA - Low Rank Alignment"))
        self.methodComboBox.setItemText(1, ("PDS - Piecewise Direct Standardization"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.renameDataLabel = QtWidgets.QLabel(self.groupBox)
        self.renameDataLabel.setObjectName("renameDataLabel")
        self.gridLayout.addWidget(self.renameDataLabel, 0, 0, 1, 1)
        self.renameDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.renameDataComboBox.setObjectName("renameDataComboBox")
        self.gridLayout.addWidget(self.renameDataComboBox, 0, 1, 1, 1)
        self.toDataLabel = QtWidgets.QLabel(self.groupBox)
        self.toDataLabel.setObjectName("toDataLabel")
        self.gridLayout.addWidget(self.toDataLabel, 0, 2, 1, 1)
        self.toDataLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.toDataLineEdit.setObjectName("toDataLineEdit")
        self.gridLayout.addWidget(self.toDataLineEdit, 0, 3, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Rename Data Set"))
        self.renameDataLabel.setText(("Rename Data"))
        self.toDataLabel.setText(("to"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from pysat.spectral.baseline_code.kajfosz_kwiatek import KajfoszKwiatek as KK

from point_spectra_gui.ui.KK import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        br = KK()
        self.topWidthSpinBox.setValue(br.top_width_)
        self.bottomWidthSpinBox.setValue(br.bottom_width_)
        self.tangentCheckBox.setChecked(br.tangent_)
        self.exponentSpinBox.setValue(br.exponent_)

    def function(self):
        methodParameters = {'top_width_': int(self.topWidthSpinBox.value()),
                            'bottom_width_': int(self.bottomWidthSpinBox.value()),
                            'tangent_': self.tangentCheckBox.isChecked(),
                            'exponent_': int(self.exponentSpinBox.value())}
        return methodParameters


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(435, 506)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName("splitter")
        self.scrollArea = QtWidgets.QScrollArea(self.splitter)
        self.scrollArea.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scrollArea.setFrameShadow(QtWidgets.QFrame.Plain)
        self.scrollArea.setLineWidth(0)
        self.scrollArea.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setAlignment(QtCore.Qt.AlignCenter)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 400, 211))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.widgetLayout = QtWidgets.QVBoxLayout()
        self.widgetLayout.setObjectName("widgetLayout")
        self.verticalLayout_3.addLayout(self.widgetLayout)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.textBrowser = QtWidgets.QTextBrowser(self.splitter)
        self.textBrowser.setEnabled(True)
        self.textBrowser.setMaximumSize(QtCore.QSize(16777215, 200))
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout.addWidget(self.splitter)
        self.progress_OK = QtWidgets.QHBoxLayout()
        self.progress_OK.setObjectName("progress_OK")
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.progress_OK.addWidget(self.progressBar)
        self.undoModulePushButton = QtWidgets.QPushButton(self.centralwidget)
        self.undoModulePushButton.setObjectName("undoModulePushButton")
        self.progress_OK.addWidget(self.undoModulePushButton)
        self.stopPushButton = QtWidgets.QPushButton(self.centralwidget)
        self.stopPushButton.setObjectName("stopPushButton")
        self.progress_OK.addWidget(self.stopPushButton)
        self.deleteModulePushButton = QtWidgets.QPushButton(self.centralwidget)
        self.deleteModulePushButton.setObjectName("deleteModulePushButton")
        self.progress_OK.addWidget(self.deleteModulePushButton)
        self.okPushButton = QtWidgets.QPushButton(self.centralwidget)
        self.okPushButton.setObjectName("okPushButton")
        self.progress_OK.addWidget(self.okPushButton)
        self.verticalLayout.addLayout(self.progress_OK)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 435, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuPreprocessing = QtWidgets.QMenu(self.menubar)
        self.menuPreprocessing.setObjectName("menuPreprocessing")
        self.menuRegression = QtWidgets.QMenu(self.menubar)
        self.menuRegression.setObjectName("menuRegression")
        self.menuVisualization = QtWidgets.QMenu(self.menubar)
        self.menuVisualization.setObjectName("menuVisualization")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuOptions = QtWidgets.QMenu(self.menubar)
        self.menuOptions.setObjectName("menuOptions")
        self.menuDark_Mode = QtWidgets.QMenu(self.menuOptions)
        self.menuDark_Mode.setObjectName("menuDark_Mode")
        self.menuDebug_Mode = QtWidgets.QMenu(self.menuOptions)
        self.menuDebug_Mode.setObjectName("menuDebug_Mode")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionRead_ChemCam_Data = QtWidgets.QAction(MainWindow)
        self.actionRead_ChemCam_Data.setObjectName("actionRead_ChemCam_Data")
        self.actionLoad_Data = QtWidgets.QAction(MainWindow)
        self.actionLoad_Data.setObjectName("actionLoad_Data")
        self.actionSet_Output_Path = QtWidgets.QAction(MainWindow)
        self.actionSet_Output_Path.setObjectName("actionSet_Output_Path")
        self.actionSave_Current_Data = QtWidgets.QAction(MainWindow)
        self.actionSave_Current_Data.setObjectName("actionSave_Current_Data")
        self.actionCreate_New_Workflow = QtWidgets.QAction(MainWindow)
        self.actionCreate_New_Workflow.setObjectName("actionCreate_New_Workflow")
        self.actionRestore_Workflow = QtWidgets.QAction(MainWindow)
        self.actionRestore_Workflow.setObjectName("actionRestore_Workflow")
        self.actionSave_Current_Workflow = QtWidgets.QAction(MainWindow)
        self.actionSave_Current_Workflow.setObjectName("actionSave_Current_Workflow")
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionRemove_Rows = QtWidgets.QAction(MainWindow)
        self.actionRemove_Rows.setObjectName("actionRemove_Rows")
        self.actionSplit_Data = QtWidgets.QAction(MainWindow)
        self.actionSplit_Data.setObjectName("actionSplit_Data")
        self.actionInterpolate = QtWidgets.QAction(MainWindow)
        self.actionInterpolate.setObjectName("actionInterpolate")
        self.actionRemove_Baseline = QtWidgets.QAction(MainWindow)
        self.actionRemove_Baseline.setObjectName("actionRemove_Baseline")
        self.actionApply_Mask = QtWidgets.QAction(MainWindow)
        self.actionApply_Mask.setObjectName("actionApply_Mask")
        self.actionPeak_Areas = QtWidgets.QAction(MainWindow)
        self.actionPeak_Areas.setObjectName("actionPeak_Areas")
        self.actionMultiply_by_Vector = QtWidgets.QAction(MainWindow)
        self.actionMultiply_by_Vector.setObjectName("actionMultiply_by_Vector")
        self.actionNormalization = QtWidgets.QAction(MainWindow)
        self.actionNormalization.setObjectName("actionNormalization")
        self.actionDimensionality_Reduction = QtWidgets.QAction(MainWindow)
        self.actionDimensionality_Reduction.setObjectName("actionDimensionality_Reduction")
        self.actionStratified_Folds = QtWidgets.QAction(MainWindow)
        self.actionStratified_Folds.setObjectName("actionStratified_Folds")
        self.actionCross_Validation = QtWidgets.QAction(MainWindow)
        self.actionCross_Validation.setObjectName("actionCross_Validation")
        self.actionTrain = QtWidgets.QAction(MainWindow)
        self.actionTrain.setObjectName("actionTrain")
        self.actionSubmodel_Predict = QtWidgets.QAction(MainWindow)
        self.actionSubmodel_Predict.setObjectName("actionSubmodel_Predict")
        self.actionPredict = QtWidgets.QAction(MainWindow)
        self.actionPredict.setObjectName("actionPredict")
        self.actionPlot = QtWidgets.QAction(MainWindow)
        self.actionPlot.setObjectName("actionPlot")
        self.actionPlot_Spectra = QtWidgets.QAction(MainWindow)
        self.actionPlot_Spectra.setObjectName("actionPlot_Spectra")
        self.actionPlot_ICA_PCA = QtWidgets.QAction(MainWindow)
        self.actionPlot_ICA_PCA.setObjectName("actionPlot_ICA_PCA")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionAbout_Qt = QtWidgets.QAction(MainWindow)
        self.actionAbout_Qt.setObjectName("actionAbout_Qt")
        self.actionOpen_Workflow = QtWidgets.QAction(MainWindow)
        self.actionOpen_Workflow.setObjectName("actionOpen_Workflow")
        self.actionOn_2 = QtWidgets.QAction(MainWindow)
        self.actionOn_2.setObjectName("actionOn_2")
        self.actionOff_2 = QtWidgets.QAction(MainWindow)
        self.actionOff_2.setObjectName("actionOff_2")
        self.actionRename_Data = QtWidgets.QAction(MainWindow)
        self.actionRename_Data.setObjectName("actionRename_Data")
        self.actionQtmodern = QtWidgets.QAction(MainWindow)
        self.actionQtmodern.setObjectName("actionQtmodern")
        self.actionDefault = QtWidgets.QAction(MainWindow)
        self.actionDefault.setObjectName("actionDefault")
        self.actionOn = QtWidgets.QAction(MainWindow)
        self.actionOn.setObjectName("actionOn")
        self.actionOff = QtWidgets.QAction(MainWindow)
        self.actionOff.setObjectName("actionOff")
        self.actionBrace_yourself = QtWidgets.QAction(MainWindow)
        self.actionBrace_yourself.setObjectName("actionBrace_yourself")
        self.actionClear_Workflow = QtWidgets.QAction(MainWindow)
        self.actionClear_Workflow.setObjectName("actionClear_Workflow")
        self.menuFile.addAction(self.actionLoad_Data)
        self.menuFile.addAction(self.actionRename_Data)
        self.menuFile.addAction(self.actionSave_Current_Data)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSet_Output_Path)
        self.menuFile.addAction(self.actionRead_ChemCam_Data)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionCreate_New_Workflow)
        self.menuFile.addAction(self.actionClear_Workflow)
        self.menuFile.addAction(self.actionRestore_Workflow)
        self.menuFile.addAction(self.actionSave_Current_Workflow)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuPreprocessing.addAction(self.actionRemove_Rows)
        self.menuPreprocessing.addAction(self.actionSplit_Data)
        self.menuPreprocessing.addAction(self.actionInterpolate)
        self.menuPreprocessing.addAction(self.actionRemove_Baseline)
        self.menuPreprocessing.addAction(self.actionApply_Mask)
        self.menuPreprocessing.addAction(self.actionPeak_Areas)
        self.menuPreprocessing.addAction(self.actionMultiply_by_Vector)
        self.menuPreprocessing.addAction(self.actionNormalization)
        self.menuPreprocessing.addAction(self.actionDimensionality_Reduction)
        self.menuPreprocessing.addAction(self.actionStratified_Folds)
        self.menuRegression.addAction(self.actionCross_Validation)
        self.menuRegression.addAction(self.actionTrain)
        self.menuRegression.addAction(self.actionPredict)
        self.menuRegression.addAction(self.actionSubmodel_Predict)
        self.menuVisualization.addAction(self.actionPlot)
        self.menuVisualization.addAction(self.actionPlot_Spectra)
        self.menuVisualization.addAction(self.actionPlot_ICA_PCA)
        self.menuHelp.addAction(self.actionAbout)
        self.menuHelp.addAction(self.actionAbout_Qt)
        self.menuDark_Mode.addAction(self.actionDefault)
        self.menuDark_Mode.addAction(self.actionBrace_yourself)
        self.menuDark_Mode.addAction(self.actionQtmodern)
        self.menuDebug_Mode.addAction(self.actionOn)
        self.menuDebug_Mode.addAction(self.actionOff)
        self.menuOptions.addAction(self.menuDark_Mode.menuAction())
        self.menuOptions.addAction(self.menuDebug_Mode.menuAction())
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuPreprocessing.menuAction())
        self.menubar.addAction(self.menuRegression.menuAction())
        self.menubar.addAction(self.menuVisualization.menuAction())
        self.menubar.addAction(self.menuOptions.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(("PYSAT Point Spectra GUI"))
        self.textBrowser.setToolTip(("<html><head/><body><p>Console window<br/>This window gives you information about your running module<br/>Errors will also show up here, if they occur</p></body></html>"))
        self.progressBar.setToolTip(("<html><head/><body><p>Your current progression.</p></body></html>"))
        self.progressBar.setFormat(("%p%"))
        self.undoModulePushButton.setToolTip(("<html><head/><body><p>Re-run your last ran module</p></body></html>"))
        self.undoModulePushButton.setText(("Re-run Module"))
        self.stopPushButton.setToolTip(("<html><head/><body><p>Completely stop the currently running module</p></body></html>"))
        self.stopPushButton.setText(("Stop Module"))
        self.deleteModulePushButton.setToolTip(("<html><head/><body><p>Delete a module that has not been ran</p></body></html>"))
        self.deleteModulePushButton.setText(("Delete Module"))
        self.okPushButton.setToolTip(("<html><head/><body><p>Press this button when you are ready to run the modules in your workflow</p></body></html>"))
        self.okPushButton.setWhatsThis(("Press this button when you\'re ready to run. (Ctrl+Enter)"))
        self.okPushButton.setText(("OK"))
        self.menuFile.setTitle(("File"))
        self.menuPreprocessing.setTitle(("Preprocessing"))
        self.menuRegression.setTitle(("Regression"))
        self.menuVisualization.setTitle(("Visualization"))
        self.menuHelp.setTitle(("Help"))
        self.menuOptions.setTitle(("Options"))
        self.menuDark_Mode.setTitle(("Theme"))
        self.menuDebug_Mode.setTitle(("Debug Mode"))
        self.actionRead_ChemCam_Data.setText(("Read ChemCam Data"))
        self.actionLoad_Data.setText(("Load Data"))
        self.actionSet_Output_Path.setText(("Set Output Path"))
        self.actionSave_Current_Data.setText(("Save Current Data"))
        self.actionCreate_New_Workflow.setText(("Create New Workflow"))
        self.actionRestore_Workflow.setText(("Restore Workflow"))
        self.actionSave_Current_Workflow.setText(("Save Current Workflow"))
        self.actionExit.setText(("Exit"))
        self.actionRemove_Rows.setText(("Remove Rows"))
        self.actionSplit_Data.setText(("Split Data"))
        self.actionInterpolate.setText(("Interpolate"))
        self.actionRemove_Baseline.setText(("Remove Baseline"))
        self.actionApply_Mask.setText(("Apply Mask"))
        self.actionPeak_Areas.setText(("Peak Areas"))
        self.actionMultiply_by_Vector.setText(("Multiply by Vector"))
        self.actionNormalization.setText(("Normalization"))
        self.actionDimensionality_Reduction.setText(("Dimensionality Reduction"))
        self.actionStratified_Folds.setText(("Stratified Folds"))
        self.actionCross_Validation.setText(("Cross Validation"))
        self.actionTrain.setText(("Regression Train"))
        self.actionSubmodel_Predict.setText(("Submodel Predict"))
        self.actionPredict.setText(("Regression Predict"))
        self.actionPlot.setText(("Plot"))
        self.actionPlot_Spectra.setText(("Plot Spectra"))
        self.actionPlot_ICA_PCA.setText(("Plot ICA/PCA"))
        self.actionAbout.setText(("About..."))
        self.actionAbout_Qt.setText(("About Qt..."))
        self.actionOpen_Workflow.setText(("Open Workflow"))
        self.actionOn_2.setText(("On"))
        self.actionOff_2.setText(("Off"))
        self.actionRename_Data.setText(("Rename Data"))
        self.actionQtmodern.setText(("qtmodern"))
        self.actionDefault.setText(("Default"))
        self.actionOn.setText(("On"))
        self.actionOff.setText(("Off"))
        self.actionBrace_yourself.setText(("Brace yourself"))
        self.actionClear_Workflow.setText(("Clear Workflow"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())




def braceyourself(MainWindow):
    MainWindow.setStyleSheet("QGroupBox {\n"
                             "  border: 2px solid gray;\n"
                             "  border-radius: 6px;\n"
                             "  margin-top: 0.5em;\n"
                             "}\n"
                             "\n"
                             "QGroupBox::title {\n"
                             "  padding-top: -10px;\n"
                             "  padding-left: 8px;\n"
                             " padding-right: 8px;\n"
                             "}")


def default(MainWindow):
    MainWindow.setStyleSheet('')



from PyQt5 import QtWidgets
from sklearn.linear_model.base import LinearRegression

from point_spectra_gui.ui.OLS import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, LinearRegression, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.fitInterceptCheckBox.setChecked(self.fit_intercept)

    def function(self):
        params = {'fit_intercept': self.fitInterceptCheckBox.isChecked()}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.chooseDataSetLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataSetLabel.setObjectName("chooseDataSetLabel")
        self.gridLayout.addWidget(self.chooseDataSetLabel, 0, 0, 1, 2)
        self.chooseDataSetComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataSetComboBox.setObjectName("chooseDataSetComboBox")
        self.gridLayout.addWidget(self.chooseDataSetComboBox, 1, 0, 1, 1)
        self.variablesToWriteLabel = QtWidgets.QLabel(self.groupBox)
        self.variablesToWriteLabel.setObjectName("variablesToWriteLabel")
        self.gridLayout.addWidget(self.variablesToWriteLabel, 2, 0, 1, 1)
        self.variablesToWriteListWidget = QtWidgets.QListWidget(self.groupBox)
        self.variablesToWriteListWidget.setObjectName("variablesToWriteListWidget")
        self.gridLayout.addWidget(self.variablesToWriteListWidget, 3, 0, 1, 2)
        self.specifyAFilenameLabel = QtWidgets.QLabel(self.groupBox)
        self.specifyAFilenameLabel.setObjectName("specifyAFilenameLabel")
        self.gridLayout.addWidget(self.specifyAFilenameLabel, 4, 0, 1, 1)
        self.specifyAFilenameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.specifyAFilenameLineEdit.setObjectName("specifyAFilenameLineEdit")
        self.gridLayout.addWidget(self.specifyAFilenameLineEdit, 5, 0, 1, 1)
        self.pushButton = QtWidgets.QPushButton(self.groupBox)
        self.pushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.gridLayout.addWidget(self.pushButton, 5, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Write to CSV"))
        self.chooseDataSetLabel.setText(("Choose data set to write to *.csv:"))
        self.variablesToWriteLabel.setText(("Variables to write:"))
        self.specifyAFilenameLabel.setText(("Specify a filename:"))
        self.specifyAFilenameLineEdit.setText(("output.csv"))
        self.pushButton.setText(("..."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# !/usr/bin/env python3
# -*- coding: utf-8 -*-
import glob
import os
import re
import sys
from io import StringIO

from point_spectra_gui import __version__

if sys.version_info < (3, 5):
    sys.exit("ERROR: You need Python 3.5 or higher to use point_spectra_gui.")

from distutils import log
from distutils.dep_util import newer
from distutils.spawn import find_executable
from setuptools import setup, Command, find_packages

PACKAGE_NAME = "point_spectra_gui"

exclude_modules = [
    'ssl', 'bz2',
    'distutils', 'unittest',
    'bdb', 'calendar', 'difflib', 'doctest', 'dummy_thread', 'gzip',
    'optparse', 'pdb', 'plistlib', 'pyexpat', 'quopri', 'repr',
    'stringio', 'tarfile', 'uu'
]

tx_executable = find_executable('tx')


def py_from_ui(uifile):
    return "%s.py" % os.path.splitext(os.path.basename(uifile))[0]


def py_from_ui_with_defaultdir(uifile):
    return os.path.join("point_spectra_gui", "ui", py_from_ui(uifile))


def ui_files():
    for uifile in glob.glob("ui/*.ui"):
        yield (uifile, py_from_ui_with_defaultdir(uifile))


class point_spectra_gui_build_ui(Command):
    description = "build Qt UI files and resources"
    user_options = [
        ("files=", None, "comma-separated list of files to rebuild"),
    ]

    def initialize_options(self):
        self.files = []

    def finalize_options(self):
        if self.files:
            files = []
            for f in self.files.split(","):
                head, tail = os.path.split(f)
                m = re.match(r'(?:ui_)?([^.]+)', tail)
                if m:
                    name = m.group(1)
                else:
                    log.warn('ignoring %r (cannot extract base name)' % f)
                    continue
                uiname = name + '.ui'
                uifile = os.path.join(head, uiname)
                if os.path.isfile(uifile):
                    pyfile = os.path.join(os.path.dirname(uifile),
                                          py_from_ui(uifile))
                    files.append((uifile, pyfile))
                else:
                    uifile = os.path.join('ui', uiname)
                    if os.path.isfile(uifile):
                        files.append((uifile,
                                      py_from_ui_with_defaultdir(uifile)))
                    else:
                        log.warn('ignoring %r' % f)
            self.files = files

    def run(self):
        from PyQt5 import uic
        _translate_re = (
            re.compile(
                r'QtGui\.QApplication.translate\(.*?, (.*?), None, '
                r'QtGui\.QApplication\.UnicodeUTF8\)'),
            re.compile(
                r'\b_translate\(.*?, (.*?)(?:, None)?\)')
        )

        def compile_ui(uifile, pyfile):
            log.info("compiling %s -> %s", uifile, pyfile)
            tmp = StringIO()
            uic.compileUi(uifile, tmp, True)
            source = tmp.getvalue()
            rc = re.compile(r'\n\n#.*?(?=\n\n)', re.MULTILINE | re.DOTALL)
            comment = ("\n\n# Automatically generated - don't edit.\n"
                       "# Use `python setup.py build_ui` to update it.")
            for r in list(_translate_re):
                source = r.sub(r'(\1)', source)
                source = rc.sub(comment, source)
            f = open(pyfile, "w")
            f.write(source)
            f.close()

        if self.files:
            for uifile, pyfile in self.files:
                compile_ui(uifile, pyfile)
        else:
            for uifile, pyfile in ui_files():
                if newer(uifile, pyfile):
                    compile_ui(uifile, pyfile)


class point_spectra_gui_clean_ui(Command):
    description = "clean up compiled Qt UI files and resources"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        for uifile, pyfile in ui_files():
            try:
                os.unlink(pyfile)
                log.info("removing %s", pyfile)
            except OSError:
                log.warn("'%s' does not exist -- can't clean it", pyfile)
        pyfile = os.path.join("point_spectra_gui", "resources.py")
        try:
            os.unlink(pyfile)
            log.info("removing %s", pyfile)
        except OSError:
            log.warn("'%s' does not exist -- can't clean it", pyfile)


setup(
    name=PACKAGE_NAME,
    version=__version__,
    scripts=['point_spectra_gui'],
    description="A PDART-funded effort to design a spectral analysis tool for LIBS (and other) spectra",
    url="https://github.com/USGS-Astrogeology/PySAT",
    author="Ryan B. Anderson, Nicholas Finch",
    author_email='rbanderson@usgs.gov, ngf4@nau.edu',
    license="Public Domain",
    keywords='PYSAT LIBS PDART Point Spectra',
    package_dir={'point_spectra_gui': 'point_spectra_gui'},
    packages=find_packages(),
    cmdclass={
        'build_ui': point_spectra_gui_build_ui,
        'clean_ui': point_spectra_gui_clean_ui,
    },
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: MacOS',
        'Operating System :: POSIX :: Linux',
        'Topic :: Scientific/Engineering',
    ]
)



from PyQt5 import QtWidgets
from sklearn.svm.classes import SVR

from point_spectra_gui.ui.SVR import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        svr = SVR()
        svr.kernel = 'rbf'
        svr.degree = 3
        svr.gamma = 'auto'
        svr.coef0 = 0.0
        svr.tol = 1e-3
        svr.C = 1.0
        svr.epsilon = 0.1
        svr.shrinking = True
        svr.cache_size = 200
        svr.verbose = False
        svr.max_iter = -1

        self.cDoubleSpinBox.setValue(svr.C)
        self.epsilonDoubleSpinBox.setValue(svr.epsilon)
        self.defaultComboItem(self.kernelComboBox, svr.kernel)
        self.degreeSpinBox.setValue(svr.degree)
        self.defaultComboItem(self.gammaComboBox, svr.gamma)
        self.coeff0DoubleSpinBox.setValue(svr.coef0)
        self.shrinkingCheckBox.setChecked(svr.shrinking)
        self.toleranceDoubleSpinBox.setValue(svr.tol)
        self.cacheSizeSpinBox.setValue(svr.cache_size)
        self.verboseCheckBox.setChecked(svr.verbose)
        self.maxIterationsSpinBox.setValue(svr.max_iter)

    def function(self):
        gamma_index = self.gammaComboBox.currentIndex()
        kernel_index = self.kernelComboBox.currentIndex()
        params = {'C': self.cDoubleSpinBox.value(),
                  'epsilon': self.epsilonDoubleSpinBox.value(),
                  'kernel': self.kernelComboBox.itemText(kernel_index),
                  'degree': self.degreeSpinBox.value(),
                  'gamma': self.gammaComboBox.itemText(gamma_index),
                  'coef0': self.coeff0DoubleSpinBox.value(),
                  'shrinking': self.shrinkingCheckBox.isChecked(),
                  'tol': self.toleranceDoubleSpinBox.value(),
                  'cache_size': self.cacheSizeSpinBox.value(),
                  'verbose': self.verboseCheckBox.isChecked(),
                  'max_iter': int(self.maxIterationsSpinBox.value())}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.ui.WriteToCSV import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class WriteToCSV(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataSetComboBox, self.datakeys)
        self.setListWidget(self.variablesToWriteListWidget, self.xvar_choices())
        self.variablesToWriteListWidget.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.chooseDataSetComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.variablesToWriteListWidget, self.xvar_choices()))
        self.pushButton.clicked.connect(self.on_pushButton_clicked)

    def function(self):
        datakey = self.chooseDataSetComboBox.currentText()
        filename = self.specifyAFilenameLineEdit.text()
        selected_cols = self.variablesToWriteListWidget.selectedItems()
        cols = []
        for selection in selected_cols:
            cols.append(selection.text())
        try:
            datatemp = self.data[datakey].df[cols]
        except:
            datatemp = self.data[datakey]['cv'][cols]

        try:
            datatemp.to_csv(self.outpath + '/' + filename)
        except:
            datatemp.to_csv(filename)

    def on_pushButton_clicked(self):
        filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None, "Save Data", self.outpath, "(*.csv)")
        self.specifyAFilenameLineEdit.setText(filename)
        if self.specifyAFilenameLineEdit.text() == "":
            self.specifyAFilenameLineEdit.setText("output.csv")

    def xvar_choices(self):
        try:
            try:
                xvarchoices = self.data[self.chooseDataSetComboBox.currentText()].df.columns.levels[0].values
            except:
                xvarchoices = self.data[self.chooseDataSetComboBox.currentText()].columns.values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = WriteToCSV()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from point_spectra_gui.core import BaselineRemoval
from point_spectra_gui.core import CrossValidation
from point_spectra_gui.core import DimensionalityReduction
from point_spectra_gui.core import Interpolation
from point_spectra_gui.core import Interpolation
from point_spectra_gui.core import LoadData
from point_spectra_gui.core import MainWindow
from point_spectra_gui.core import MaskData
from point_spectra_gui.core import MultiplyByVector
from point_spectra_gui.core import Normalization
from point_spectra_gui.core import OutputFolder
from point_spectra_gui.core import PeakAreas
from point_spectra_gui.core import Plot
from point_spectra_gui.core import PlotSpectra
from point_spectra_gui.core import Plot_ICA_PCA
from point_spectra_gui.core import ReadChemCamData
from point_spectra_gui.core import RegressionPredict
from point_spectra_gui.core import RegressionTrain
from point_spectra_gui.core import RemoveRows
from point_spectra_gui.core import RenameData
from point_spectra_gui.core import SplitDataset
from point_spectra_gui.core import StratifiedFolds
from point_spectra_gui.core import SubmodelPredict
from point_spectra_gui.core import WriteToCSV
from point_spectra_gui.core.regressionMethods import *




from PyQt5 import QtWidgets

from point_spectra_gui.ui.Interpolation import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Interpolation(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setComboBox(self.interpolateDataComboBox, self.datakeys)
        self.setComboBox(self.referenceDataComboBox, self.datakeys)

    def function(self):
        datakey_to_interp = self.interpolateDataComboBox.currentText()
        datakey_ref = self.referenceDataComboBox.currentText()
        print(self.data[datakey_ref].df.columns.levels[0])
        try:
            self.data[datakey_to_interp].interp(self.data[datakey_ref].df['wvl'].columns)
        except Exception as e:
            print(e)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = Interpolation()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.cLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cLabel.setObjectName("cLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.cLabel)
        self.cDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.cDoubleSpinBox.setProperty("value", 1.0)
        self.cDoubleSpinBox.setObjectName("cDoubleSpinBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cDoubleSpinBox)
        self.epsilonLabel = QtWidgets.QLabel(self.formGroupBox)
        self.epsilonLabel.setObjectName("epsilonLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.epsilonLabel)
        self.epsilonDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.epsilonDoubleSpinBox.setProperty("value", 0.1)
        self.epsilonDoubleSpinBox.setObjectName("epsilonDoubleSpinBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.epsilonDoubleSpinBox)
        self.kernelLabel = QtWidgets.QLabel(self.formGroupBox)
        self.kernelLabel.setObjectName("kernelLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.kernelLabel)
        self.kernelComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.kernelComboBox.setObjectName("kernelComboBox")
        self.kernelComboBox.addItem("")
        self.kernelComboBox.addItem("")
        self.kernelComboBox.addItem("")
        self.kernelComboBox.addItem("")
        self.kernelComboBox.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.kernelComboBox)
        self.degreeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.degreeLabel.setObjectName("degreeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.degreeLabel)
        self.degreeSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.degreeSpinBox.setObjectName("degreeSpinBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.degreeSpinBox)
        self.gammaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.gammaLabel.setObjectName("gammaLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.gammaLabel)
        self.gammaComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.gammaComboBox.setObjectName("gammaComboBox")
        self.gammaComboBox.addItem("")
        self.gammaComboBox.addItem("")
        self.gammaComboBox.addItem("")
        self.gammaComboBox.addItem("")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.gammaComboBox)
        self.coeff0Label = QtWidgets.QLabel(self.formGroupBox)
        self.coeff0Label.setObjectName("coeff0Label")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.coeff0Label)
        self.coeff0DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.coeff0DoubleSpinBox.setObjectName("coeff0DoubleSpinBox")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.coeff0DoubleSpinBox)
        self.shrinkingLabel = QtWidgets.QLabel(self.formGroupBox)
        self.shrinkingLabel.setObjectName("shrinkingLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.shrinkingLabel)
        self.shrinkingCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.shrinkingCheckBox.setObjectName("shrinkingCheckBox")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.shrinkingCheckBox)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.toleranceDoubleSpinBox.setDecimals(3)
        self.toleranceDoubleSpinBox.setProperty("value", 0.001)
        self.toleranceDoubleSpinBox.setObjectName("toleranceDoubleSpinBox")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.toleranceDoubleSpinBox)
        self.cacheSizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cacheSizeLabel.setObjectName("cacheSizeLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.cacheSizeLabel)
        self.cacheSizeSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.cacheSizeSpinBox.setMaximum(999)
        self.cacheSizeSpinBox.setProperty("value", 200)
        self.cacheSizeSpinBox.setObjectName("cacheSizeSpinBox")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.cacheSizeSpinBox)
        self.verboseLabel = QtWidgets.QLabel(self.formGroupBox)
        self.verboseLabel.setObjectName("verboseLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.verboseLabel)
        self.verboseCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.verboseCheckBox.setObjectName("verboseCheckBox")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.verboseCheckBox)
        self.maxIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.maxIterationsLabel.setObjectName("maxIterationsLabel")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.maxIterationsLabel)
        self.maxIterationsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.maxIterationsSpinBox.setMinimum(-1)
        self.maxIterationsSpinBox.setMaximum(9999999)
        self.maxIterationsSpinBox.setProperty("value", -1)
        self.maxIterationsSpinBox.setObjectName("maxIterationsSpinBox")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.maxIterationsSpinBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.cLabel.setText(("C"))
        self.epsilonLabel.setText(("Epsilon"))
        self.kernelLabel.setText(("Kernel"))
        self.kernelComboBox.setItemText(0, ("rbf"))
        self.kernelComboBox.setItemText(1, ("poly"))
        self.kernelComboBox.setItemText(2, ("sigmoid"))
        self.kernelComboBox.setItemText(3, ("linear"))
        self.kernelComboBox.setItemText(4, ("precomputed"))
        self.degreeLabel.setText(("Degree"))
        self.gammaLabel.setText(("Gamma"))
        self.gammaComboBox.setItemText(0, ("auto"))
        self.gammaComboBox.setItemText(1, ("rbf"))
        self.gammaComboBox.setItemText(2, ("poly"))
        self.gammaComboBox.setItemText(3, ("sigmoid"))
        self.coeff0Label.setText(("Coeff 0"))
        self.shrinkingLabel.setText(("Shrinking"))
        self.toleranceLabel.setText(("Tolerance"))
        self.cacheSizeLabel.setText(("Cache Size"))
        self.verboseLabel.setText(("Verbose"))
        self.maxIterationsLabel.setText(("Max Iterations"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.precomputeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.precomputeLabel.setObjectName("precomputeLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.precomputeLabel)
        self.precomputeComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.precomputeComboBox.setObjectName("precomputeComboBox")
        self.precomputeComboBox.addItem("")
        self.precomputeComboBox.addItem("")
        self.precomputeComboBox.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.precomputeComboBox)
        self.cVLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cVLabel.setObjectName("cVLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.cVLabel)
        self.cVCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.cVCheckBox.setObjectName("cVCheckBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.cVCheckBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.normalizeLabel.setText(("Normalize"))
        self.precomputeLabel.setText(("Precompute"))
        self.precomputeComboBox.setItemText(0, ("auto"))
        self.precomputeComboBox.setItemText(1, ("True"))
        self.precomputeComboBox.setItemText(2, ("False"))
        self.cVLabel.setText(("CV"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.linear_model.least_angle import LassoLars, LassoLarsCV, LassoLarsIC

from point_spectra_gui.ui.LassoLARS import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        # LassoLARS
        ll = LassoLars()
        self.alphaDoubleSpinBox.setValue(ll.alpha)
        self.fit_interceptCheckBox.setChecked(ll.fit_intercept)
        self.verboseCheckBox.setChecked(ll.verbose)
        self.normalizeCheckBox.setChecked(ll.normalize)
        self.setComboBox(self.precomputeComboBox, ['True', 'False', 'auto', 'array-like'])
        self.defaultComboItem(self.precomputeComboBox, ll.precompute)
        self.max_iterSpinBox.setValue(ll.max_iter)
        self.copy_XCheckBox.setChecked(ll.copy_X)
        self.fit_pathCheckBox.setChecked(ll.fit_path)
        self.positiveCheckBox.setChecked(ll.positive)

        # LassoLarsCV
        llcv = LassoLarsCV()
        self.max_n_alphasSpinBox.setValue(llcv.max_n_alphas)
        self.n_jobsSpinBox.setValue(llcv.n_jobs)

        # LassoLarsIC
        llic = LassoLarsIC()
        self.cvSpinBox.setValue(3)
        self.setComboBox(self.criterionComboBox, ['aic', 'bic'])
        self.defaultComboItem(self.criterionComboBox, llic.criterion)

    def function(self):
        model = self.modelComboBox.currentIndex()
        if model == 0:
            params = {
                'alpha': self.alphaDoubleSpinBox.value(),
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'verbose': self.fit_interceptCheckBox.isChecked(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': self.precomputeComboBox.currentText(),
                'max_iter': self.max_iterSpinBox.value(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'fit_path': self.fit_pathCheckBox.isChecked(),
                'positive': self.positiveCheckBox.isChecked(),
                'model': model
            }
        elif model == 1:
            params = {
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'verbose': self.fit_interceptCheckBox.isChecked(),
                'max_iter': self.max_iterSpinBox.value(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': self.precomputeComboBox.currentText(),
                'cv': self.cvSpinBox.value(),
                'max_n_alphas': self.max_n_alphasSpinBox.value(),
                'n_jobs': self.n_jobsSpinBox.value(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'positive': self.positiveCheckBox.isChecked(),
                'model': model
            }
        elif model == 2:
            params = {
                'criterion': self.criterionComboBox.currentText(),
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'verbose': self.fit_interceptCheckBox.isChecked(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': self.precomputeComboBox.currentText(),
                'max_iter': self.max_iterSpinBox.value(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'positive': self.positiveCheckBox.isChecked(),
                'model': model
            }
        else:
            params = {}
            print("Error")

        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.ui.Normalization import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class normWidgets:
    def __init__(self, minimumWLabel, minimumWSpinBox, maximumWLabel, maximumWSpinBox):
        self.minimumWLabel = minimumWLabel
        self.minimumWSpinBox = minimumWSpinBox
        self.maximumWLabel = maximumWLabel
        self.maximumWSpinBox = maximumWSpinBox

    def setHidden(self, bool):
        self.minimumWLabel.setHidden(bool)
        self.minimumWSpinBox.setHidden(bool)
        self.maximumWLabel.setHidden(bool)
        self.maximumWSpinBox.setHidden(bool)

    def getValues(self):
        return int(self.minimumWSpinBox.text()), int(self.maximumWSpinBox.text())

    def setMaximum(self, int_):
        self.minimumWSpinBox.setMaximum(int_)
        self.maximumWSpinBox.setMaximum(int_)

    def setValue(self, int_):
        self.minimumWSpinBox.setValue(int_)
        self.maximumWSpinBox.setValue(int_)

    def spinBox(self, int_):
        if int_ == 0:
            return self.minimumWSpinBox
        elif int_ == 1:
            return self.maximumWSpinBox
        else:
            return "Not a valid number"


class Normalization(Ui_Form, Basics):
    def __init__(self):
        super().__init__()
        self.normwidgets = []
        self.all_boxes = []
        self.index = 1

    def setupUi(self, Form):
        self.__init__()
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setupWidgets()
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.varToNormalizeListWidget, self.xvar_choices()))
        self.setListWidget(self.varToNormalizeListWidget, self.xvar_choices())
        self.setMaximum(9999999)
        self.setHidden(self.normwidgets)
        self.qt.isGuiChanged(self.checkForNewMax)
        self.rangeCountSpinBox.setMinimum(1)
        self.rangeCountSpinBox.setMaximum(15)
        self.rangeCountSpinBox.valueChanged.connect(self.on_change_rangeCountPushButton)

    def on_change_rangeCountPushButton(self):
        spin = int(self.rangeCountSpinBox.value())
        while self.index < spin:
            self.on_addRange_pushed()
        while self.index > spin:
            self.on_deleteRange_pushed()

    def setHidden(self, list):
        for i in range(1, len(list)):
            list[i].setHidden(True)

    def setMaximum(self, int_):
        for items in self.normwidgets:
            items.setMaximum(int_)

    def on_addRange_pushed(self):
        if self.index < len(self.normwidgets):
            self.normwidgets[self.index].setHidden(False)
            self.index += 1
        else:
            print("Cannot add more wavelengths")

    def on_deleteRange_pushed(self):
        if self.index > 1:
            self.index -= 1
            self.normwidgets[self.index].setHidden(True)
            self.normwidgets[self.index].setValue(0)
        else:
            print("Cannot delete any more wavelengths")

    def setupWidgets(self):
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel, self.minimumWavelengthSpinBox,
                                            self.maximumWavelengthLabel, self.maximumWavelengthSpinBox))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_2, self.minimumWavelengthSpinBox_2,
                                            self.maximumWavelengthLabel_2, self.maximumWavelengthSpinBox_2))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_3, self.minimumWavelengthSpinBox_3,
                                            self.maximumWavelengthLabel_3, self.maximumWavelengthSpinBox_3))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_4, self.minimumWavelengthSpinBox_4,
                                            self.maximumWavelengthLabel_4, self.maximumWavelengthSpinBox_4))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_5, self.minimumWavelengthSpinBox_5,
                                            self.maximumWavelengthLabel_5, self.maximumWavelengthSpinBox_5))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_6, self.minimumWavelengthSpinBox_6,
                                            self.maximumWavelengthLabel_6, self.maximumWavelengthSpinBox_6))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_7, self.minimumWavelengthSpinBox_7,
                                            self.maximumWavelengthLabel_7, self.maximumWavelengthSpinBox_7))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_8, self.minimumWavelengthSpinBox_8,
                                            self.maximumWavelengthLabel_8, self.maximumWavelengthSpinBox_8))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_9, self.minimumWavelengthSpinBox_9,
                                            self.maximumWavelengthLabel_9, self.maximumWavelengthSpinBox_9))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_10, self.minimumWavelengthSpinBox_10,
                                            self.maximumWavelengthLabel_10, self.maximumWavelengthSpinBox_10))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_11, self.minimumWavelengthSpinBox_11,
                                            self.maximumWavelengthLabel_11, self.maximumWavelengthSpinBox_11))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_12, self.minimumWavelengthSpinBox_12,
                                            self.maximumWavelengthLabel_12, self.maximumWavelengthSpinBox_12))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_13, self.minimumWavelengthSpinBox_13,
                                            self.maximumWavelengthLabel_13, self.maximumWavelengthSpinBox_13))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_14, self.minimumWavelengthSpinBox_14,
                                            self.maximumWavelengthLabel_14, self.maximumWavelengthSpinBox_14))
        self.normwidgets.append(normWidgets(self.minimumWavelengthLabel_15, self.minimumWavelengthSpinBox_15,
                                            self.maximumWavelengthLabel_15, self.maximumWavelengthSpinBox_15))
        for i in range(len(self.normwidgets)):
            for j in range(0, 2):
                self.all_boxes.append(self.normwidgets[i].spinBox(j))

    def checkForNewMax(self):
        for i in range(len(self.all_boxes) - 1):
            self.all_boxes[i].valueChanged.connect(self.all_boxes[i + 1].setMinimum)

    def xvar_choices(self):
        try:
            try:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[
                    0].values
            except:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].columns.values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices

    def function(self):
        ranges = []
        for i in range(self.index):
            ranges.append(self.normwidgets[i].getValues())
        datakey = self.chooseDataComboBox.currentText()
        try:
            col_var = self.varToNormalizeListWidget.currentItem().text()
        except:
            print("Did you remember to select a variable?")
        print("{}".format(ranges))
        try:
            self.data[datakey].norm(ranges, col_var)
            print("Normalization has been applied to the ranges: " + str(ranges))
        except Exception as e:
            print("There was a problem: ", e)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Normalization()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupbox = QtWidgets.QGroupBox(Form)
        self.groupbox.setObjectName("groupbox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupbox)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.largestWaveletScaleLabel = QtWidgets.QLabel(self.groupbox)
        self.largestWaveletScaleLabel.setObjectName("largestWaveletScaleLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.largestWaveletScaleLabel)
        self.largestWaveletScaleSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.largestWaveletScaleSpinBox.setObjectName("largestWaveletScaleSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.largestWaveletScaleSpinBox)
        self.lowestWaveletScaleLabel = QtWidgets.QLabel(self.groupbox)
        self.lowestWaveletScaleLabel.setObjectName("lowestWaveletScaleLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.lowestWaveletScaleLabel)
        self.lowestWaveletScaleSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.lowestWaveletScaleSpinBox.setObjectName("lowestWaveletScaleSpinBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lowestWaveletScaleSpinBox)
        self.interpolationMethodLabel = QtWidgets.QLabel(self.groupbox)
        self.interpolationMethodLabel.setObjectName("interpolationMethodLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.interpolationMethodLabel)
        self.interpolationMethodComboBox = QtWidgets.QComboBox(self.groupbox)
        self.interpolationMethodComboBox.setObjectName("interpolationMethodComboBox")
        self.interpolationMethodComboBox.addItem("")
        self.interpolationMethodComboBox.addItem("")
        self.interpolationMethodComboBox.addItem("")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.interpolationMethodComboBox)
        self.verticalLayout.addWidget(self.groupbox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.largestWaveletScaleLabel.setText(("Largest Wavelet Scale"))
        self.lowestWaveletScaleLabel.setText(("Lowest Wavelet Scale"))
        self.interpolationMethodLabel.setText(("Interpolation Method"))
        self.interpolationMethodComboBox.setItemText(0, ("Spline"))
        self.interpolationMethodComboBox.setItemText(1, ("Quadratic"))
        self.interpolationMethodComboBox.setItemText(2, ("Linear"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets

from point_spectra_gui.ui.RenameData import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class RenameData(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.renameDataComboBox, self.datakeys)

    def function(self):
        self.datakeys.append(self.toDataLineEdit.text())
        self.data[self.toDataLineEdit.text()] = self.data[self.renameDataComboBox.currentText()]
        for i in range(len(self.datakeys) - 1):
            if self.datakeys[i] == self.renameDataComboBox.currentText():
                del self.datakeys[i]


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = RenameData()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.topLayout = QtWidgets.QGridLayout()
        self.topLayout.setObjectName("topLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.topLayout.addWidget(self.chooseDataLabel, 0, 0, 1, 1)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setToolTip("")
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.topLayout.addWidget(self.chooseDataComboBox, 0, 1, 1, 1)
        self.figureNameLabel = QtWidgets.QLabel(self.groupBox)
        self.figureNameLabel.setObjectName("figureNameLabel")
        self.topLayout.addWidget(self.figureNameLabel, 2, 0, 1, 1)
        self.figureNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.figureNameLineEdit.setObjectName("figureNameLineEdit")
        self.topLayout.addWidget(self.figureNameLineEdit, 2, 1, 1, 1)
        self.plotTitleLabel = QtWidgets.QLabel(self.groupBox)
        self.plotTitleLabel.setObjectName("plotTitleLabel")
        self.topLayout.addWidget(self.plotTitleLabel, 3, 0, 1, 1)
        self.plotTitleLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotTitleLineEdit.setObjectName("plotTitleLineEdit")
        self.topLayout.addWidget(self.plotTitleLineEdit, 3, 1, 1, 1)
        self.figureNameComboBox = QtWidgets.QComboBox(self.groupBox)
        self.figureNameComboBox.setObjectName("figureNameComboBox")
        self.topLayout.addWidget(self.figureNameComboBox, 1, 1, 1, 1)
        self.figureLabel = QtWidgets.QLabel(self.groupBox)
        self.figureLabel.setObjectName("figureLabel")
        self.topLayout.addWidget(self.figureLabel, 1, 0, 1, 1)
        self.verticalLayout.addLayout(self.topLayout)
        self.line = QtWidgets.QFrame(self.groupBox)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.XYLayout = QtWidgets.QHBoxLayout()
        self.XYLayout.setObjectName("XYLayout")
        self.xLayout = QtWidgets.QFormLayout()
        self.xLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.xLayout.setObjectName("xLayout")
        self.chooseXVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseXVariableLabel.setObjectName("chooseXVariableLabel")
        self.xLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseXVariableLabel)
        self.chooseXVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseXVariableComboBox.setObjectName("chooseXVariableComboBox")
        self.xLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseXVariableComboBox)
        self.xTitleLabel = QtWidgets.QLabel(self.groupBox)
        self.xTitleLabel.setObjectName("xTitleLabel")
        self.xLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.xTitleLabel)
        self.xTitleLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.xTitleLineEdit.setObjectName("xTitleLineEdit")
        self.xLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.xTitleLineEdit)
        self.xMinLabel = QtWidgets.QLabel(self.groupBox)
        self.xMinLabel.setObjectName("xMinLabel")
        self.xLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.xMinLabel)
        self.xMaxLabel = QtWidgets.QLabel(self.groupBox)
        self.xMaxLabel.setObjectName("xMaxLabel")
        self.xLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.xMaxLabel)
        self.xMinDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.xMinDoubleSpinBox.setObjectName("xMinDoubleSpinBox")
        self.xLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.xMinDoubleSpinBox)
        self.xMaxDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.xMaxDoubleSpinBox.setObjectName("xMaxDoubleSpinBox")
        self.xLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.xMaxDoubleSpinBox)
        self.XYLayout.addLayout(self.xLayout)
        self.yLayout = QtWidgets.QFormLayout()
        self.yLayout.setObjectName("yLayout")
        self.chooseYVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseYVariableLabel.setObjectName("chooseYVariableLabel")
        self.yLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseYVariableLabel)
        self.chooseYVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseYVariableComboBox.setObjectName("chooseYVariableComboBox")
        self.yLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseYVariableComboBox)
        self.yTitleLabel = QtWidgets.QLabel(self.groupBox)
        self.yTitleLabel.setObjectName("yTitleLabel")
        self.yLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.yTitleLabel)
        self.yTitleLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.yTitleLineEdit.setObjectName("yTitleLineEdit")
        self.yLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.yTitleLineEdit)
        self.yMinLabel = QtWidgets.QLabel(self.groupBox)
        self.yMinLabel.setObjectName("yMinLabel")
        self.yLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.yMinLabel)
        self.yMaxLabel = QtWidgets.QLabel(self.groupBox)
        self.yMaxLabel.setObjectName("yMaxLabel")
        self.yLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.yMaxLabel)
        self.yMinDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.yMinDoubleSpinBox.setObjectName("yMinDoubleSpinBox")
        self.yLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.yMinDoubleSpinBox)
        self.yMaxDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.yMaxDoubleSpinBox.setObjectName("yMaxDoubleSpinBox")
        self.yLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.yMaxDoubleSpinBox)
        self.XYLayout.addLayout(self.yLayout)
        self.verticalLayout.addLayout(self.XYLayout)
        self.line_2 = QtWidgets.QFrame(self.groupBox)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.botLayout = QtWidgets.QGridLayout()
        self.botLayout.setObjectName("botLayout")
        self.oneToOneLabel = QtWidgets.QLabel(self.groupBox)
        self.oneToOneLabel.setObjectName("oneToOneLabel")
        self.botLayout.addWidget(self.oneToOneLabel, 1, 0, 1, 1)
        self.legendLabel = QtWidgets.QLabel(self.groupBox)
        self.legendLabel.setObjectName("legendLabel")
        self.botLayout.addWidget(self.legendLabel, 0, 0, 1, 1)
        self.alphaLabel = QtWidgets.QLabel(self.groupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.botLayout.addWidget(self.alphaLabel, 5, 0, 1, 1)
        self.markerLabel = QtWidgets.QLabel(self.groupBox)
        self.markerLabel.setObjectName("markerLabel")
        self.botLayout.addWidget(self.markerLabel, 4, 0, 1, 1)
        self.alphaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.alphaDoubleSpinBox.setObjectName("alphaDoubleSpinBox")
        self.botLayout.addWidget(self.alphaDoubleSpinBox, 5, 1, 1, 1)
        self.plotFilenameLabel = QtWidgets.QLabel(self.groupBox)
        self.plotFilenameLabel.setObjectName("plotFilenameLabel")
        self.botLayout.addWidget(self.plotFilenameLabel, 6, 0, 1, 1)
        self.lineComboBox = QtWidgets.QComboBox(self.groupBox)
        self.lineComboBox.setObjectName("lineComboBox")
        self.botLayout.addWidget(self.lineComboBox, 3, 1, 1, 1)
        self.lineLabel = QtWidgets.QLabel(self.groupBox)
        self.lineLabel.setObjectName("lineLabel")
        self.botLayout.addWidget(self.lineLabel, 3, 0, 1, 1)
        self.plotFilenameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotFilenameLineEdit.setReadOnly(True)
        self.plotFilenameLineEdit.setObjectName("plotFilenameLineEdit")
        self.botLayout.addWidget(self.plotFilenameLineEdit, 6, 1, 1, 1)
        self.colorComboBox = QtWidgets.QComboBox(self.groupBox)
        self.colorComboBox.setObjectName("colorComboBox")
        self.botLayout.addWidget(self.colorComboBox, 2, 1, 1, 1)
        self.colorLabel = QtWidgets.QLabel(self.groupBox)
        self.colorLabel.setObjectName("colorLabel")
        self.botLayout.addWidget(self.colorLabel, 2, 0, 1, 1)
        self.markerComboBox = QtWidgets.QComboBox(self.groupBox)
        self.markerComboBox.setObjectName("markerComboBox")
        self.botLayout.addWidget(self.markerComboBox, 4, 1, 1, 1)
        self.plotFilenamePushButton = QtWidgets.QPushButton(self.groupBox)
        self.plotFilenamePushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.plotFilenamePushButton.setObjectName("plotFilenamePushButton")
        self.botLayout.addWidget(self.plotFilenamePushButton, 6, 2, 1, 1)
        self.legendLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.legendLineEdit.setObjectName("legendLineEdit")
        self.botLayout.addWidget(self.legendLineEdit, 0, 1, 1, 1)
        self.oneToOneCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.oneToOneCheckBox.setText("")
        self.oneToOneCheckBox.setObjectName("oneToOneCheckBox")
        self.botLayout.addWidget(self.oneToOneCheckBox, 1, 1, 1, 1)
        self.verticalLayout.addLayout(self.botLayout)
        self.verticalLayout_2.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.chooseDataComboBox, self.figureNameLineEdit)
        Form.setTabOrder(self.figureNameLineEdit, self.plotTitleLineEdit)
        Form.setTabOrder(self.plotTitleLineEdit, self.chooseXVariableComboBox)
        Form.setTabOrder(self.chooseXVariableComboBox, self.xTitleLineEdit)
        Form.setTabOrder(self.xTitleLineEdit, self.xMinDoubleSpinBox)
        Form.setTabOrder(self.xMinDoubleSpinBox, self.xMaxDoubleSpinBox)
        Form.setTabOrder(self.xMaxDoubleSpinBox, self.chooseYVariableComboBox)
        Form.setTabOrder(self.chooseYVariableComboBox, self.yTitleLineEdit)
        Form.setTabOrder(self.yTitleLineEdit, self.yMinDoubleSpinBox)
        Form.setTabOrder(self.yMinDoubleSpinBox, self.yMaxDoubleSpinBox)
        Form.setTabOrder(self.yMaxDoubleSpinBox, self.legendLineEdit)
        Form.setTabOrder(self.legendLineEdit, self.oneToOneCheckBox)
        Form.setTabOrder(self.oneToOneCheckBox, self.colorComboBox)
        Form.setTabOrder(self.colorComboBox, self.lineComboBox)
        Form.setTabOrder(self.lineComboBox, self.markerComboBox)
        Form.setTabOrder(self.markerComboBox, self.alphaDoubleSpinBox)
        Form.setTabOrder(self.alphaDoubleSpinBox, self.plotFilenameLineEdit)
        Form.setTabOrder(self.plotFilenameLineEdit, self.plotFilenamePushButton)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Plot"))
        self.chooseDataLabel.setText(("Choose data"))
        self.figureNameLabel.setText(("Figure name"))
        self.plotTitleLabel.setText(("Plot Title"))
        self.figureNameComboBox.setToolTip(("Already have a figure, select from the ones available here"))
        self.figureLabel.setText(("Select an existing figure name"))
        self.chooseXVariableLabel.setText(("Choose X Variable"))
        self.xTitleLabel.setText(("X title"))
        self.xMinLabel.setText(("X min"))
        self.xMaxLabel.setText(("X max"))
        self.chooseYVariableLabel.setText(("Choose Y Variable"))
        self.yTitleLabel.setText(("Y title"))
        self.yMinLabel.setText(("Y min"))
        self.yMaxLabel.setText(("X max"))
        self.oneToOneLabel.setText(("One to One"))
        self.legendLabel.setText(("Legend"))
        self.alphaLabel.setText(("Alpha"))
        self.markerLabel.setText(("Marker"))
        self.plotFilenameLabel.setText(("Plot Filename"))
        self.lineLabel.setText(("Line"))
        self.colorLabel.setText(("Color"))
        self.plotFilenamePushButton.setText(("..."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

